package main

import (
	"log"
	"ocl/portainer-devtool/configs"
	"ocl/portainer-devtool/tasks"
	"ocl/portainer-devtool/tasks/common"
)

func main() {
	config, err := configs.GetConfig()
	if err != nil {
		log.Fatalln(err)
	}

	config.Summarize()

	// Init tasks
	taskItems := []common.Tasker{
		tasks.NewListRepositoryMenuTask(config),
		tasks.NewListOperationMenuTask(config),
		tasks.NewGenerateJwtTokenTask(config),
		tasks.NewTestEnvironmentTask(),
		tasks.NewCurlLookupTask(),
		tasks.NewCodeSecurityScanTask(),
		tasks.NewInstallDockerTask(),
		tasks.NewListDevToolCommandTask(config),
	}

	for _, taskItem := range taskItems {
		taskItem.SetParentTaskers(taskItems)
	}

	common.ListCommandMenu(taskItems, "Which repository of action do you want to operate:", true, nil)
}
